@@ -29,7 +29,6 @@
 #include "openssl-include.h"
 
 #include "gtlscertificate-openssl.h"
-#include "openssl-util.h"
 #include <glib/gi18n-lib.h>
 
 struct _GTlsCertificateOpenssl
@@ -342,6 +341,7 @@ g_tls_certificate_openssl_set_property (GObject      *object,
   guint8 *data;
   BIO *bio;
   const char *string;
+  char error_buffer[256];
 
   switch (prop_id)
     {
@@ -357,10 +357,11 @@ g_tls_certificate_openssl_set_property (GObject      *object,
         openssl->have_cert = TRUE;
       else if (!openssl->construct_error)
         {
+          ERR_error_string_n (ERR_get_error (), error_buffer, sizeof (error_buffer));
           openssl->construct_error =
             g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
                          _("Could not parse DER certificate: %s"),
-                         ERR_error_string (ERR_get_error (), NULL));
+                         error_buffer);
         }
 
       break;
@@ -377,10 +378,11 @@ g_tls_certificate_openssl_set_property (GObject      *object,
         openssl->have_cert = TRUE;
       else if (!openssl->construct_error)
         {
+          ERR_error_string_n (ERR_get_error (), error_buffer, sizeof (error_buffer));
           openssl->construct_error =
             g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
                          _("Could not parse PEM certificate: %s"),
-                         ERR_error_string (ERR_get_error (), NULL));
+                         error_buffer);
         }
       break;
 
@@ -396,10 +398,11 @@ g_tls_certificate_openssl_set_property (GObject      *object,
         openssl->have_key = TRUE;
       else if (!openssl->construct_error)
         {
+          ERR_error_string_n (ERR_get_error (), error_buffer, sizeof (error_buffer));
           openssl->construct_error =
             g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
                          _("Could not parse DER private key: %s"),
-                         ERR_error_string (ERR_get_error (), NULL));
+                         error_buffer);
         }
       break;
 
@@ -415,10 +418,11 @@ g_tls_certificate_openssl_set_property (GObject      *object,
         openssl->have_key = TRUE;
       else if (!openssl->construct_error)
         {
+          ERR_error_string_n (ERR_get_error (), error_buffer, sizeof (error_buffer));
           openssl->construct_error =
             g_error_new (G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE,
                          _("Could not parse PEM private key: %s"),
-                         ERR_error_string (ERR_get_error (), NULL));
+                         error_buffer);
         }
       break;
 
@@ -468,7 +472,6 @@ g_tls_certificate_openssl_verify (GTlsCertificate     *cert,
   GTlsCertificateFlags gtls_flags;
   X509 *x;
   STACK_OF(X509) *untrusted;
-  gint i;
 
   cert_openssl = G_TLS_CERTIFICATE_OPENSSL (cert);
   x = cert_openssl->cert;
@@ -510,22 +513,6 @@ g_tls_certificate_openssl_verify (GTlsCertificate     *cert,
       X509_STORE_free (store);
     }
 
-  /* We have to check these ourselves since openssl
-   * does not give us flags and UNKNOWN_CA will take priority.
-   */
-  for (i = 0; i < sk_X509_num (untrusted); i++)
-    {
-      X509 *c = sk_X509_value (untrusted, i);
-      ASN1_TIME *not_before = X509_get_notBefore (c);
-      ASN1_TIME *not_after = X509_get_notAfter (c);
-
-      if (X509_cmp_current_time (not_before) > 0)
-        gtls_flags |= G_TLS_CERTIFICATE_NOT_ACTIVATED;
-
-      if (X509_cmp_current_time (not_after) < 0)
-        gtls_flags |= G_TLS_CERTIFICATE_EXPIRED;
-    }
-
   sk_X509_free (untrusted);
 
   if (identity)
@@ -663,7 +650,7 @@ verify_identity_hostname (GTlsCertificateOpenssl *openssl,
   else
     return FALSE;
 
-  return g_tls_X509_check_host (openssl->cert, hostname, strlen (hostname), 0, NULL) == 1;
+  return X509_check_host (openssl->cert, hostname, strlen (hostname), 0, NULL) == 1;
 }
 
 static gboolean
@@ -695,7 +682,7 @@ verify_identity_ip (GTlsCertificateOpenssl *openssl,
   addr_bytes = g_inet_address_to_bytes (addr);
   addr_size = g_inet_address_get_native_size (addr);
 
-  ret = g_tls_X509_check_ip (openssl->cert, addr_bytes, addr_size, 0) == 1;
+  ret = X509_check_ip (openssl->cert, addr_bytes, addr_size, 0) == 1;
 
   g_object_unref (addr);
   return ret;
